@@ -47,6 +47,7 @@
 #include <QPainter>
 #include <QPrintDialog>
 #include <QPrinter>
+#include <QStringEncoder>
 #include <QTextStream>
 #include <QVBoxLayout>
 #include <QWidget>
@@ -755,3 +756,5 @@ void KgpgEditor::newText()
 	setCaption(i18n("Untitled"), false);
 	slotResetEncoding(false);
 }
+
+#include "moc_kgpgeditor.cpp"
