@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2012-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -55,7 +55,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgSignText() override;
+	~KGpgSignText() override = default;
 
 	/**
 	 * @brief get signing result
