@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2009-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -38,7 +38,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgSignUid() override;
+	~KGpgSignUid() override = default;
 
 	/**
 	 * @brief set node to sign
